#[non_exhaustive]
pub enum Request<'a> { Destroy, AttachBuffer { buffer: WlBuffer, }, DamageBuffer { x: i32, y: i32, width: i32, height: i32, }, Capture, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy this object

Destroys the frame. This request can be sent at any time by the client.

This is a destructor, once sent this object cannot be used any longer.



AttachBuffer

attach buffer to session

Attach a buffer to the session.

The wl_buffer.release request is unused.

The new buffer replaces any previously attached buffer.

This request must not be sent after capture, or else the already_captured protocol error is raised.

Fields

buffer: WlBuffer


DamageBuffer

damage buffer

Apply damage to the buffer which is to be captured next. This request may be sent multiple times to describe a region.

The client indicates the accumulated damage since this wl_buffer was last captured. During capture, the compositor will update the buffer with at least the union of the region passed by the client and the region advertised by ext_image_copy_capture_frame_v1.damage.

When a wl_buffer is captured for the first time, or when the client doesn’t track damage, the client must damage the whole buffer.

This is for optimisation purposes. The compositor may use this information to reduce copying.

These coordinates originate from the upper left corner of the buffer.

If x or y are strictly negative, or if width or height are negative or zero, the invalid_buffer_damage protocol error is raised.

This request must not be sent after capture, or else the already_captured protocol error is raised.

Fields

x: i32

region x coordinate

y: i32

region y coordinate

width: i32

region width

height: i32

region height



Capture

capture a frame

Capture a frame.

Unless this is the first successful captured frame performed in this session, the compositor may wait an indefinite amount of time for the source content to change before performing the copy.

This request may only be sent once, or else the already_captured protocol error is raised. A buffer must be attached before this request is sent, or else the no_buffer protocol error is raised.

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message